import Vue from 'nativescript-vue';
import cssToObj from '../../utils/css-to-obj';

const layoutTypes = {
  absolute: 'AbsoluteLayout',
  dock: 'DockLayout',
  flex: 'FlexboxLayout',
  grid: 'GridLayout',
  stack: 'StackLayout',
  wrap: 'WrapLayout',
};
layoutTypes.block = layoutTypes.stack;
layoutTypes.default = layoutTypes.stack;

export default Vue.extend({
  name: 'div',

  props: {
    lStyle: {
      type: [String, Object],
    },
  },
  computed: {
    layoutName() {
      return layoutTypes[this.layoutStyle.display];
    },
    layoutStyle() {
      let customLayoutStyle = {};
      const defaultLayoutStyle = {
        display: 'block',
      };

      if (typeof this.lStyle === 'string') {
        customLayoutStyle = cssToObj(this.lStyle);
      } else if (this.lStyle === 'object') {
        customLayoutStyle = this.lStyle;
      }

      return { ...defaultLayoutStyle, ...customLayoutStyle };
    },
  },

  render(h) {
    return h(
      this.layoutName,
      {
        props: this.layoutStyle,
        attrs: this.layoutStyle,
      },
      this.$slots.default,
    );
  },
});
